---
title: Anlyea Quadcopter - Design phase
date: 2016-04-18 00:00:00
---

I started working on a custom Quadcopter for fun. I started from the
[Crossfire by MickeyB](https://www.thingiverse.com/thing:234867) from which
I redesigned large portions to better fit my needs.

![Crossfire 2 Original](crossfire_original.jpg "Original Crossfire 2")

I wanted a somewhat smaller design so that it fits inside a Rako box for
transport. I started using the original arms but then, the original center
piece was too large for the Quad to fit inside the 600mm x 400mm x 120mm
Rako box I had on hand. As the difference was not that large, I decided
to design a new replacement part using [OpenSCAD](http://www.openscad.org)
because, hey, why not ?

If you don't know OpenSCAD, it's a program and a language to describe and
design 3D objects. Instead of drawing like you would usually, you program
what the object looks like using operations and primitive objects. In my
case, in this object, the hole for the existing arm can be described as
four 3mm holes for the screws that will go through the arms.

I decided to create a module that will take the angle of the arm as a parameter
so that the module can be instanciated four times with the different angles.

    module arm_hole(angle) {
        rotate([0, 0, angle]) {
            translate([-12.5, -14, 1.9])
                cylinder(d = 3, center = true, h = 4);
            translate([ 13  , -14, 1.9])
                cylinder(d = 3, center = true, h = 4);
            translate([-12.5,  11.5, 1.9])
                cylinder(d = 3, center = true, h = 4);
            translate([ 13  ,  11.5, 1.9])
                cylinder(d = 3, center = true, h = 4);
        }
    }

I continued to redesign the central parts as needed: One top plate, one
bottom plate, a new battery holder that can be mounted on the bottom, an
adapter for the flight controller on top, ... This continued until I only
kept the arms.

The first flight was ... chaotic to say the least. As it was my first design,
I was thinking about a lot of details that would prove to be useless or
wrong. For example, I wanted to put the battery on the bottom because it
was the only place where there was some room left. And for some reason I
wanted to reduce the vibrations to the battery. If you already designed
or even tried a Quadcopter, you will see the missing part in my reasoning:
The battery is the heaviest part of the copter and it was moving as a
pendulum below the copter as the flightcontroller was frantically trying
to correct the level of the craft. Not enough to crash it downright, but
enough to get really rough rides with autolevel and sluggish ones with
manual control of the level.

The Anlyea copter is still in the design phase as I try more designs that
are readily available, print them and study how they fly. I will post a
new article with the full designs once it can fly for longer than 10 seconds
and it doesn't repeatedly crash into the nearest pool, but for now, it
sits confortably into its Rako case.
